<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_US">
<context>
    <name>LockScreen</name>
    <message>
        <location filename="../screenlocker/qml/LockScreen.qml" line="202"/>
        <source>Password</source>
        <translation>Password</translation>
    </message>
    <message>
        <location filename="../screenlocker/qml/LockScreen.qml" line="225"/>
        <source>Unlock</source>
        <translation>Unlock</translation>
    </message>
    <message>
        <location filename="../screenlocker/qml/LockScreen.qml" line="274"/>
        <source>Please enter your password</source>
        <translation>Please enter your password</translation>
    </message>
    <message>
        <location filename="../screenlocker/qml/LockScreen.qml" line="284"/>
        <source>Unlocking failed</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
